@@ -9,7 +9,7 @@ use Carp;
 
 use Exporter qw{ import };
 
-our $VERSION = '0.104_01';
+our $VERSION = '0.105_01';
 
 our @EXPORT_OK = qw{
     meta_merge
@@ -67,7 +67,8 @@ sub required_module_versions {
         'Perl::Critic::Policy'      => 1.119,
         'Perl::Critic::Utils'       => 1.119,
         'PPI::Token::Symbol'        => 0,
-        'PPIx::QuoteLike'           => 0.005,
+        'PPIx::QuoteLike'           => 0.011,   # For full scope inside ""
+        'PPIx::Regexp'              => 0.071,   # For full scope inside //
         'Readonly'                  => 0,
         'Scalar::Util'              => 0,
         @args,
